@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1500';
+our $VERSION = '0.1600';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -53,11 +53,10 @@ sub parse {
     die 'No chord to parse'
         unless $chord;
 
-    my $note_re  = qr/[A-G][#b]?[#b]?/;
+    my $note_re = qr/[A-G][#b]?[#b]?/;
 
     # Get the roman representation of the scale
     my @scale = $self->_get_scale_mode;
-
     print "SCALE: @scale\n" if $self->verbose;
 
     my @notes;
@@ -90,6 +89,19 @@ sub parse {
     # Get just the note part of the chord name
     ( my $note = $chord ) =~ s/^($note_re).*$/$1/;
 
+    my %bb_enharmonics = (
+        Cbb => 'Bb', #[qw/ Bb A# /],
+        Dbb => 'C',  #[qw/ C B# /],
+        Ebb => 'D',  #[qw/ D /],
+        Fbb => 'Eb', #[qw/ Eb D# /],
+        Gbb => 'F',  #[qw/ F /],
+        Abb => 'G',  #[qw/ G /],
+        Bbb => 'A',  #[qw/ A /],
+    );
+
+    $note = $bb_enharmonics{$note}
+        if $note =~ /bb$/;
+
     # Get the roman representation based on the scale position
     my $position = first_index { $_ eq $note } @notes;
 
@@ -290,7 +302,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1500
+version 0.1600
 
 =head1 SYNOPSIS
 
@@ -428,12 +440,14 @@ thus producing C<II7>.
 If a major/minor chord designation is not provided, C<M> major is
 assumed.
 
-A diminished chord may be given as either C<o> or C<dim>.
-
 If the B<chords> attribute is set to C<0>, the B<scale_name> is used
 to figure out the correct Roman numeral representation.
 
-Trying to parse a double flatted chord will not work.
+A diminished chord may be given as either C<o> or C<dim>.
+Half-diminished (C<m7b5>) chords can be given as C<ø>.  A decoration
+of C<△> may be given for say the C<△7> major seventh chord.
+
+Parsing a double flatted chord will only work in select cases.
 
 =head1 SEE ALSO
 
@@ -454,7 +468,8 @@ significantly powerful.
 
 =head1 THANK YOU
 
-Dan Book L<DBOOK|https://metacpan.org/author/DBOOK> for the list rotation logic
+Dan Book (L<DBOOK|https://metacpan.org/author/DBOOK>) for the list
+rotation logic
 
 =head1 AUTHOR
 
